guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

06/08: gnu: system: Do not activate firmware when activating a container


From: David Thompson
Subject: 06/08: gnu: system: Do not activate firmware when activating a container.
Date: Sat, 13 Jun 2015 03:44:27 +0000

davexunit pushed a commit to branch wip-container
in repository guix.

commit 00d602081ffd5e6dd7f3d6e02dbc84e2d16cc300
Author: David Thompson <address@hidden>
Date:   Mon Jun 8 08:59:51 2015 -0400

    gnu: system: Do not activate firmware when activating a container.
    
    * gnu/system.scm (operating-system-activation-script): Add #:container?
      keyword argument.  Don't call 'activate-firmware' when 'container?' is #t.
---
 gnu/system.scm |   11 +++++++----
 1 files changed, 7 insertions(+), 4 deletions(-)

diff --git a/gnu/system.scm b/gnu/system.scm
index 92ed454..8346a38 100644
--- a/gnu/system.scm
+++ b/gnu/system.scm
@@ -682,7 +682,7 @@ variable is not set---hence the need for this wrapper."
                       (apply execl #$modprobe
                              (cons #$modprobe (cdr (command-line))))))))
 
-(define (operating-system-activation-script os)
+(define* (operating-system-activation-script os #:key container?)
   "Return the activation script for OS---i.e., the code that \"activates\" the
 stateful part of OS, including user accounts and groups, special directories,
 etc."
@@ -755,9 +755,12 @@ etc."
                     ;; Tell the kernel to use our 'modprobe' command.
                     (activate-modprobe #$modprobe)
 
-                    ;; Tell the kernel where firmware is.
-                    (activate-firmware
-                     (string-append #$firmware "/lib/firmware"))
+                    ;; Tell the kernel where firmware is, unless we are
+                    ;; activating a container.
+                    #$@(if container?
+                           #~()
+                           #~(activate-firmware
+                              (string-append #$firmware "/lib/firmware")))
 
                     ;; Let users debug their own processes!
                     (activate-ptrace-attach)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]